.. This is the template for the credentials section of a provider tutorial
.. You can't include this verbatim as you could with templates/fetch.rst, but you can use it as a starting point

Credentials
-----------

Finally, we need to add credentials to the resource group.  OpenStack provides several ways to provide credentials. LinchPin supports some of these methods for passing credentials for use with OpenStack resources.

.. include:: ../credentials/{{ provider }}.rst

.. inclusion-marker-second-section-end
